==> haskell-data-binary-ieee754-0.4.4-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-binary-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-binary-ieee754
version:              0.4.4
visibility:           public
id:                   data-binary-ieee754-0.4.4-JFCv5iwsUHQ3ijGpBz7Bjn
key:                  data-binary-ieee754-0.4.4-JFCv5iwsUHQ3ijGpBz7Bjn
license:              MIT
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/data-binary-ieee754/
synopsis:             Parser/Serialiser for IEEE-754 floating-point values
description:          Convert Float and Decimal values to/from raw octets.
category:             Data
abi:                  92d09eebf764e62c056da9879a6f4ee2
exposed:              True
exposed-modules:      Data.Binary.IEEE754
import-dirs:          /usr/lib/ghc-8.8.3/site-local/data-binary-ieee754-0.4.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/data-binary-ieee754-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/data-binary-ieee754-0.4.4
hs-libraries:         HSdata-binary-ieee754-0.4.4-JFCv5iwsUHQ3ijGpBz7Bjn
depends:              base-4.13.0.0 binary-0.8.7.0
haddock-interfaces:
    /usr/share/doc/haskell-data-binary-ieee754/html/data-binary-ieee754.haddock

haddock-html:         /usr/share/doc/haskell-data-binary-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-binary-ieee754-0.4.4-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-binary-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-binary-ieee754
version:              0.4.4
visibility:           public
id:                   data-binary-ieee754-0.4.4-K62zgbvjZdWGqG22TUshLD
key:                  data-binary-ieee754-0.4.4-K62zgbvjZdWGqG22TUshLD
license:              MIT
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/data-binary-ieee754/
synopsis:             Parser/Serialiser for IEEE-754 floating-point values
description:          Convert Float and Decimal values to/from raw octets.
category:             Data
abi:                  c403754a5a405882d4dbeed065477ac4
exposed:              True
exposed-modules:      Data.Binary.IEEE754
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-binary-ieee754-0.4.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-binary-ieee754-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/data-binary-ieee754-0.4.4

hs-libraries:         HSdata-binary-ieee754-0.4.4-K62zgbvjZdWGqG22TUshLD
depends:              base-4.14.0.0 binary-0.8.8.0
haddock-interfaces:
    /usr/share/doc/haskell-data-binary-ieee754/html/data-binary-ieee754.haddock

haddock-html:         /usr/share/doc/haskell-data-binary-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
